@@ -13,7 +13,7 @@ use Router::Generic;
 use ASP4::ConfigLoader;
 use vars __PACKAGE__->VARS;
 
-our $VERSION = '0.009';
+our $VERSION = '0.010';
 
 
 sub handler : method
@@ -23,6 +23,8 @@ sub handler : method
   $ENV{DOCUMENT_ROOT} = $r->document_root;
   my $res = $class->SUPER::handler( $r );
   
+  return $res if -f $r->document_root . $r->uri || -d $r->document_root . $r->uri;
+  
   my $router = $class->get_router()
     or return $res;
   my @matches = $router->match( $r->uri . ( $r->args ? '?' . $r->args : '' ), $r->method )
@@ -68,6 +70,7 @@ sub run
 {
   my ($s, $context) = @_;
   
+  return $Response->Declined if -f $Server->MapPath( $context->r->uri ) || -d $Server->MapPath( $context->r->uri );
   return $Response->Declined if $context->r->pnotes('__routed');
   my $router = $s->get_router()
     or return $Response->Declined;
